import logging
from logging import Formatter, Logger, StreamHandler

DEFAULT_FORMAT = "[%(levelname)s] %(asctime)s %(filename)s.%(funcName)s: %(message)30s"


def build(name: str) -> Logger:
    log = logging.getLogger(name)
    log.setLevel(logging.DEBUG)
    log.propagate = False
    log.addHandler(_get_handler())
    return log


def _get_handler() -> StreamHandler:
    handler = StreamHandler()
    handler.setFormatter(Formatter(DEFAULT_FORMAT))
    return handler



from http import HTTPStatus


class ServerError(Exception):
    status = HTTPStatus.INTERNAL_SERVER_ERROR


class NotFoundError(ServerError):
    status = HTTPStatus.NOT_FOUND


class MethodNotAllowedError(ServerError):
    status = HTTPStatus.METHOD_NOT_ALLOWED
